@@ -1,4 +1,7 @@
-#    Copyright 2021 Province of British Columbia
+# Copyright 2015-2023 Province of British Columbia
+# Copyright 2021 Environment and Climate Change Canada
+# Copyright 2023-2024 Australian Government Department of Climate Change, 
+# Energy, the Environment and Water
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -15,21 +18,10 @@
 test_that("ssd_plot", {
   expect_snapshot_plot(ssd_plot(ssddata::ccme_boron, boron_pred), "boron_pred")
   expect_snapshot_plot(ssd_plot(ssddata::ccme_boron, boron_pred, label = "Species"), "boron_pred_label")
-  expect_snapshot_plot(ssd_plot(ssddata::ccme_boron, boron_pred, label = "Species",
-                                shift_x = 2), "boron_pred_shift_x")
-  testthat::skip_on_ci()
-  testthat::skip_on_cran()
-  expect_snapshot_plot(ssd_plot(ssddata::ccme_boron, boron_pred, ribbon = TRUE), "boron_pred_ribbon")
-})
-
-test_that("ssd_plot censored data", {
-  data <- ssddata::ccme_boron
-  data$Other <- data$Conc * 2
-  expect_snapshot_plot(ssd_plot(data, boron_pred, right = "Other"), "boron_cens_pred")
-  expect_snapshot_plot(ssd_plot(data, boron_pred, right = "Other", label = "Species"), "boron_cens_pred_species")
-  testthat::skip_on_ci()
-  testthat::skip_on_cran()
-  expect_snapshot_plot(ssd_plot(data, boron_pred, right = "Other", ribbon = TRUE), "boron_cens_pred_ribbon")
+  expect_snapshot_plot(ssd_plot(ssddata::ccme_boron, boron_pred,
+    label = "Species",
+    shift_x = 2
+  ), "boron_pred_shift_x")
 })
 
 test_that("ssd_plot aes", {
@@ -38,8 +30,25 @@ test_that("ssd_plot aes", {
   expect_snapshot_plot(ssd_plot(data, boron_pred, shape = "Group"), "boron_shape")
 })
 
+test_that("ssd_plot ribbon", {
+  data <- ssddata::ccme_boron
+  expect_snapshot_plot(ssd_plot(data, boron_pred, ribbon = TRUE), "ribbon")
+  expect_snapshot_plot(ssd_plot(data, boron_pred, ribbon = FALSE), "no_ribbon")
+})
+
 test_that("ssd_plot xbreaks", {
-  expect_snapshot_plot(ssd_plot(ssddata::ccme_boron, boron_pred, xbreaks = c(1,2)), "boron_breaks")
+  expect_snapshot_plot(ssd_plot(ssddata::ccme_boron, boron_pred, xbreaks = c(1, 2)), "boron_breaks")
+})
+
+test_that("ssd_plot language", {
+  data <- ssddata::ccme_boron
+  data$Conc <- data$Conc * 100
+  boron_pred <- ssdtools::boron_pred
+  boron_pred$est <- boron_pred$est * 100
+  boron_pred$lcl <- boron_pred$lcl * 100
+  boron_pred$ucl <- boron_pred$ucl * 100
+  expect_snapshot_plot(ssd_plot(data, boron_pred, big.mark = " "), "boron_bigmark")
+  expect_snapshot_plot(ssd_plot(data, boron_pred, suffix = " %%"), "suffix")
 })
 
 test_that("ssd_plot can't handles missing values all", {
@@ -50,10 +59,12 @@ test_that("ssd_plot can't handles missing values all", {
 
 test_that("ssd_plot fills in missing order", {
   data <- ssddata::ccme_boron
-  data <- data[order(data$Conc),]
+  data <- data[order(data$Conc), ]
   data$Other <- data$Conc
   data$Conc[1] <- NA
   data$Other[nrow(data)] <- NA
-  expect_snapshot_plot(ssd_plot(data, boron_pred, right = "Other", bounds = c(right = 2)),
-                       "missing_order")
+  expect_snapshot_plot(
+    ssd_plot(data, boron_pred, right = "Other", bounds = c(right = 2)),
+    "missing_order"
+  )
 })
